| Title: | Mechanistic Functional Response Analysis |
| Version: | 1.0.4 |
| Description: | Implements the mechanistic functional response model proposed by Okuyama (2012) <doi:10.1016/j.biocontrol.2011.10.008> for host-parasitoid systems. Provides tools for model fitting, likelihood profiling, stochastic simulation, and visualization of parasitism distributions. Includes an interactive 'shiny' application for complete analysis workflows, built with 'plotly' for interactive graphics and 'rmarkdown' for reproducible reports. |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| Depends: | R (≥ 4.1.0) |
| Imports: | DEoptim, dplyr, future, ggplot2 (≥ 3.4.0), magrittr, parallel, plotly, rlang, rmarkdown, shiny, shinyBS, shinythemes, stats, utils |
| Suggests: | kableExtra, knitr, testthat (≥ 3.0.0) |
| URL: | https://github.com/Segon03/funresMech |
| BugReports: | https://github.com/Segon03/funresMech/issues |
| Config/testthat/edition: | 3 |
| Config/Needs/check: | r-lib/actions/dependencies |
| Config/roxygen2/version: | 8.1.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-09-15 03:38:09 UTC; Equipo |
| Author: | Segundo Núñez-Campero [aut, cre] |
| Maintainer: | Segundo Núñez-Campero <segundo.nc@conicet.gov.ar> |
| Repository: | CRAN |
| Date/Publication: | 2026-09-24 14:50:02 UTC |
Run the funresMech Shiny App
Description
Launches the interactive application for mechanistic functional response analysis, based on the Okuyama model.
Usage
run_app(...)
Arguments
... |
Additional arguments passed to |
Value
This function launches a Shiny app and does not return a value.
Examples
if (interactive()) {
run_app()
}